# winwin lib

## 安装说明


```
pip install winwin
pip install git+https://github.com/zbmain/winwin.git
pip install winwin -i http://localhost:19900/simple/ --trusted-host localhost
```

## 使用说明

```import winnwin```